from textwrap import wrap

from django.forms import fields

def form_to_text_table(form, width=74, sep=' | '):
    output_list = []

    for field_name in form.declared_fields:
        # Determine basic field data
        field = form.declared_fields[field_name]
        label = field.label

        # Determine field value depending on field type
        if isinstance(field, fields.ChoiceField):
            value = dict(field.choices)[form.cleaned_data[field_name]]
        else:
            value = form.cleaned_data[field_name]
        value = str(value)

        # Store in output list
        output_list.append((label, value))

    # Determine maximum field widths
    max_label = max([len(_[0]) for _ in output_list])
    max_value = width - len(sep) - max_label

    # Generate result text
    res = []
    for label, value in output_list:
        # Wrap value to lines
        lines = wrap(value, max_value)

        if lines:
            # Output first line with label name
            res.append('%s%s%s' % (label.rjust(max_label), sep, lines.pop(0)))

            # Output following lines without label, if any
            for line in lines:
                res.append('%s%s%s' % (' '*max_label, sep, line))
        else:
            # Output empty label row
            res.append('%s%s' % (label.rjust(max_label), sep))

    # Build text block and return
    return '\n'.join(res)
